
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) INRIA - Allan CORNET
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*--------------------------------------------------------------------------*/ 
#ifndef __LOADBACKGROUNDCLASSPATH_H__
#define __LOADBACKGROUNDCLASSPATH_H__

#include "dynlib_jvm.h"
#include "BOOL.h"

/**
* load classpath in background
* @return TRUE or FALSE
*/
JVM_IMPEXP BOOL loadBackGroundClassPath(void);

#endif /* __LOADBACKGROUNDCLASSPATH_H__ */
/*--------------------------------------------------------------------------*/ 
